@@ -25,7 +25,9 @@
 #include <QtWebKit/QWebView>
 #include <QtWebKit/QWebFrame>
 #include <QtWebKit/QWebElement>
+#include <QtNetwork/QNetworkReply>
 #include <QtNetwork/QNetworkProxy>
+#include <QtNetwork/QSslError>
 
 #include <qjson/parser.h>
 
@@ -40,6 +42,21 @@
 
 using namespace KGAPI2;
 
+WebView::WebView(QWidget *parent)
+    : QWebView(parent)
+{
+}
+
+
+WebView::~WebView()
+{
+
+}
+
+void WebView::contextMenuEvent(QContextMenuEvent *)
+{
+    //Not menu
+}
 
 AuthWidget::Private::Private(AuthWidget *parent):
     QObject(),
@@ -72,16 +89,28 @@ void AuthWidget::Private::setupUi()
     progressbar->setValue(0);
     vbox->addWidget(progressbar);
 
-    webview = new QWebView(q);
+    webview = new WebView(q);
     KIO::AccessManager *m = new KIO::AccessManager(webview);
     webview->page()->networkAccessManager()->setProxyFactory(m->proxyFactory());
+    connect(webview->page()->networkAccessManager(), SIGNAL(sslErrors(QNetworkReply*,QList<QSslError>)),
+            this, SLOT(onSslError(QNetworkReply*,QList<QSslError>)));
+
 
     vbox->addWidget(webview);
     connect(webview, SIGNAL(loadProgress(int)), progressbar, SLOT(setValue(int)));
     connect(webview, SIGNAL(urlChanged(QUrl)), this, SLOT(webviewUrlChanged(QUrl)));
-    connect(webview, SIGNAL(loadFinished(bool)), this, SLOT(webviewFinished()));
+    connect(webview, SIGNAL(loadFinished(bool)), this, SLOT(webviewFinished(bool)));
 }
 
+void AuthWidget::Private::onSslError(QNetworkReply *reply, const QList<QSslError> &errors)
+{
+    Q_FOREACH (const QSslError &error, errors) {
+        KGAPIDebug() << "SSL ERROR: " << error.errorString();
+    }
+    reply->ignoreSslErrors();
+}
+
+
 void AuthWidget::Private::setProgress(AuthWidget::Progress progress)
 {
     KGAPIDebug() << progress;
@@ -118,8 +147,12 @@ void AuthWidget::Private::webviewUrlChanged(const QUrl &url)
     }
 }
 
-void AuthWidget::Private::webviewFinished()
+void AuthWidget::Private::webviewFinished(bool ok)
 {
+    if (!ok) {
+        KGAPIWarning() << "Failed to load" << webview->url();
+    }
+
     QUrl url = webview->url();
     KGAPIDebug() << url;
 
